@@ -92,7 +92,7 @@ class FilesystemController(BaseController):
             else:
                 fname = 'probe-data.json'
             with open(os.path.join(self.block_log_dir, fname), 'w') as fp:
-                json.dump(storage, fp)
+                json.dump(storage, fp, indent=4)
             self.model.load_probe_data(storage)
         except Exception:
             block_discover_log.exception(
@@ -123,7 +123,7 @@ class FilesystemController(BaseController):
     def _reprobe(self):
         self._probe_state = ProbeState.REPROBING
         self.run_in_bg(
-            lambda: self._bg_probe(["blockdev"]),
+            lambda: self._bg_probe({"blockdev"}),
             lambda fut: self._probed(fut, True),
             )
 
