@@ -13,31 +13,51 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
+import os
 
 from subiquitycore.controller import BaseController
 
 from subiquity.ui.views import WelcomeView
-from subiquity.models import WelcomeModel
+
+
+log = logging.getLogger('subiquity.controllers.welcome')
 
 
 class WelcomeController(BaseController):
 
     def __init__(self, common):
         super().__init__(common)
-        self.model = WelcomeModel()
+        self.model = self.base_model.locale
+        self.answers = self.all_answers.get("Welcome", {})
+        log.debug("Welcome: answers=%s", self.answers)
+
+    def start(self):
+        lang = os.environ.get("LANG")
+        if lang.endswith(".UTF-8"):
+            lang = lang.rsplit('.', 1)[0]
+        for code, name in self.model.supported_languages:
+            if code == lang:
+                self.model.switch_language(code)
 
     def default(self):
-        title = "Wilkommen! Bienvenue! Welcome! Zdrastvutie! Welkom!"
-        excerpt = "Please choose your preferred language"
-        footer = ("Use UP, DOWN and ENTER keys to select your language.")
-        self.ui.set_header(title, excerpt)
-        self.ui.set_footer(footer)
         view = WelcomeView(self.model, self)
         self.ui.set_body(view)
+        if 'lang' in self.answers:
+            self.done(self.answers['lang'])
 
-    def done(self):
+    def done(self, code):
+        log.debug("WelcomeController.done %s next-screen")
+        self.signal.emit_signal('l10n:language-selected', code)
+        self.model.switch_language(code)
         self.signal.emit_signal('next-screen')
 
     def cancel(self):
         # Can't go back from here!
         pass
+
+    def serialize(self):
+        return self.model.selected_language
+
+    def deserialize(self, data):
+        self.model.switch_language(data)
